#!/bin/env perl

use strict;
use File::Basename qw(dirname);
use feature qw(say);
use lib qw(. Install);
use Hotfix qw(GetHostName);

use DE_EPAGES::Core::API::File qw ( CopyDirectory RunOnGlob );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);

sub Main {
    local $| = 1;

    chdir dirname $0;

    my $BackupDir = '../Backup-'. GetHostName();
    return unless -d '../FileChanges';
    chdir '../FileChanges';

    return if not -d 'srv/epages/eproot' and $^O eq 'MSWin32';

    SystemCommand( '/etc/init.d/epages6 perm all -d srv/epages/eproot', { Print => 1 })
        unless $^O eq 'MSWin32';

    RunOnGlob( 'srv/epages/eproot/Cartridges/DE_EPAGES', '*/Data/WebRoot', sub {
        say qq(CopyDirectory($_, $ENV{EPAGES_WEBROOT}, $BackupDir));
        CopyDirectory($_, $ENV{EPAGES_WEBROOT}, $BackupDir, {by => 'perl', stat => 'preserve'});
               }
        );

    my $ShopImport = 'srv/epages/eproot/Cartridges/DE_EPAGES/ShopConfiguration/Data/Private/ShopImport';
    CopyDirectory($ShopImport, "$ENV{EPAGES_STORES}/Site/ShopImport",
                  $BackupDir, {by => 'perl', stat => 'preserve'}) if -d $ShopImport;

    if ($^O eq 'MSWin32') {
        say qq(CopyDirectory('srv/epages/eproot', $ENV{EPAGES}, $BackupDir));
        CopyDirectory('srv/epages/eproot', $ENV{EPAGES}, $BackupDir, { by => 'perl' });
        return;
    }

    say qq(CopyDirectory('.', '/', $BackupDir));
    CopyDirectory('.', '/', $BackupDir, {by => 'perl', stat => 'preserve'});
    SystemCommand( '/etc/init.d/epages6 perm admin', { Print => 1 });
}

RunScript(
    'Sub' => \&Main
);
